From d43295365b4751742834c167c971d9042ed92f93 Mon Sep 17 00:00:00 2001
From: Stanislav Brabec <sbrabec@suse.com>
Date: Fri, 24 Jul 2015 21:27:04 +0200
Subject: [PATCH 11/12] Introduce --with-external-uuidd

libuuid has a circular dependency on uuidd. However this dependency is
only a run-time dependency. Introduce --with-external-uuidd, which makes
possible to compile libuuid which is aware of uuidd even if build of
uuidd itself is disabled.

Signed-off-by: Stanislav Brabec <sbrabec@suse.com>
---
 configure.ac | 6 +++++-
 1 file changed, 5 insertions(+), 1 deletion(-)

diff --git a/configure.ac b/configure.ac
index 48191b3..410b3fb 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1049,7 +1049,12 @@ AC_ARG_ENABLE([uuidd],
 )
 UL_BUILD_INIT([uuidd])
 UL_REQUIRES_BUILD([uuidd], [libuuid])
-AS_IF([test "x$build_uuidd" = xyes], [
+AC_ARG_WITH([external-uuidd], [
+  AS_HELP_STRING([--with-external-uuidd], [use external uuidd])], [
+    AS_VAR_SET([build_uuidd], [yes])
+    AS_VAR_SET([ext_uuidd], [yes])
+])
+AS_IF([test "x$build_uuidd" = xyes -o "x$ext_uuidd" = xyes ], [
   AC_DEFINE([HAVE_UUIDD], [1], [Define to 1 if you want to use uuid daemon.])
 ])
 AM_CONDITIONAL([BUILD_UUIDD], [test "x$build_uuidd" = xyes])
-- 
2.4.5

